# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: PdmObject.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='PdmObject.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fPdmObject.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\"T\n\x1aPdmDescendantObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x15\n\rchild_keyword\x18\x02 \x01(\t\"M\n\x15PdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\"j\n\x1b\x43reatePdmChildObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x13\n\x0b\x63hild_field\x18\x02 \x01(\t\x12\x15\n\rclass_keyword\x18\x03 \x01(\t\"Q\n\x16PdmParentObjectRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x16\n\x0eparent_keyword\x18\x02 \x01(\t\"\xc0\x01\n\tPdmObject\x12\x15\n\rclass_keyword\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x04\x12\x33\n\nparameters\x18\x03 \x03(\x0b\x32\x1f.rips.PdmObject.ParametersEntry\x12\x0f\n\x07visible\x18\x04 \x01(\x08\x12\x12\n\npersistent\x18\x05 \x01(\x08\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\x0ePdmObjectArray\x12 \n\x07objects\x18\x01 \x03(\x0b\x32\x0f.rips.PdmObject\"I\n\x16PdmObjectGetterRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\"[\n\x16PdmObjectSetterRequest\x12-\n\x07request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectGetterRequest\x12\x12\n\ndata_count\x18\x02 \x01(\x05\"\xbf\x01\n\x14PdmObjectSetterChunk\x12\x33\n\x0bset_request\x18\x01 \x01(\x0b\x32\x1c.rips.PdmObjectSetterRequestH\x00\x12$\n\x07\x64oubles\x18\x02 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x03 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x04 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"\x1b\n\x0b\x44oubleArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"\x18\n\x08IntArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x05\"\x1b\n\x0bStringArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\"\x8a\x01\n\x14PdmObjectGetterReply\x12$\n\x07\x64oubles\x18\x01 \x01(\x0b\x32\x11.rips.DoubleArrayH\x00\x12\x1e\n\x04ints\x18\x02 \x01(\x0b\x32\x0e.rips.IntArrayH\x00\x12$\n\x07strings\x18\x03 \x01(\x0b\x32\x11.rips.StringArrayH\x00\x42\x06\n\x04\x64\x61ta\"j\n\x16PdmObjectMethodRequest\x12\x1f\n\x06object\x18\x01 \x01(\x0b\x32\x0f.rips.PdmObject\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x1f\n\x06params\x18\x03 \x01(\x0b\x32\x0f.rips.PdmObject2\xf9\x04\n\x10PdmObjectService\x12S\n\x17GetDescendantPdmObjects\x12 .rips.PdmDescendantObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12I\n\x12GetChildPdmObjects\x12\x1b.rips.PdmChildObjectRequest\x1a\x14.rips.PdmObjectArray\"\x00\x12G\n\x14GetAncestorPdmObject\x12\x1c.rips.PdmParentObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12L\n\x14\x43reateChildPdmObject\x12!.rips.CreatePdmChildObjectRequest\x1a\x0f.rips.PdmObject\"\x00\x12\x39\n\x17UpdateExistingPdmObject\x12\x0f.rips.PdmObject\x1a\x0b.rips.Empty\"\x00\x12S\n\x13\x43\x61llPdmObjectGetter\x12\x1c.rips.PdmObjectGetterRequest\x1a\x1a.rips.PdmObjectGetterReply\"\x00\x30\x01\x12V\n\x13\x43\x61llPdmObjectSetter\x12\x1a.rips.PdmObjectSetterChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x12\x46\n\x13\x43\x61llPdmObjectMethod\x12\x1c.rips.PdmObjectMethodRequest\x1a\x0f.rips.PdmObject\"\x00\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,])




_PDMDESCENDANTOBJECTREQUEST = _descriptor.Descriptor(
  name='PdmDescendantObjectRequest',
  full_name='rips.PdmDescendantObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmDescendantObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_keyword', full_name='rips.PdmDescendantObjectRequest.child_keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=128,
)


_PDMCHILDOBJECTREQUEST = _descriptor.Descriptor(
  name='PdmChildObjectRequest',
  full_name='rips.PdmChildObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmChildObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_field', full_name='rips.PdmChildObjectRequest.child_field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=207,
)


_CREATEPDMCHILDOBJECTREQUEST = _descriptor.Descriptor(
  name='CreatePdmChildObjectRequest',
  full_name='rips.CreatePdmChildObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.CreatePdmChildObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_field', full_name='rips.CreatePdmChildObjectRequest.child_field', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_keyword', full_name='rips.CreatePdmChildObjectRequest.class_keyword', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=315,
)


_PDMPARENTOBJECTREQUEST = _descriptor.Descriptor(
  name='PdmParentObjectRequest',
  full_name='rips.PdmParentObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmParentObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_keyword', full_name='rips.PdmParentObjectRequest.parent_keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=398,
)


_PDMOBJECT_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='rips.PdmObject.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='rips.PdmObject.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='rips.PdmObject.ParametersEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=593,
)

_PDMOBJECT = _descriptor.Descriptor(
  name='PdmObject',
  full_name='rips.PdmObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_keyword', full_name='rips.PdmObject.class_keyword', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='rips.PdmObject.address', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='rips.PdmObject.parameters', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='visible', full_name='rips.PdmObject.visible', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='rips.PdmObject.persistent', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PDMOBJECT_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=593,
)


_PDMOBJECTARRAY = _descriptor.Descriptor(
  name='PdmObjectArray',
  full_name='rips.PdmObjectArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='rips.PdmObjectArray.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=645,
)


_PDMOBJECTGETTERREQUEST = _descriptor.Descriptor(
  name='PdmObjectGetterRequest',
  full_name='rips.PdmObjectGetterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmObjectGetterRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='rips.PdmObjectGetterRequest.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=720,
)


_PDMOBJECTSETTERREQUEST = _descriptor.Descriptor(
  name='PdmObjectSetterRequest',
  full_name='rips.PdmObjectSetterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='rips.PdmObjectSetterRequest.request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_count', full_name='rips.PdmObjectSetterRequest.data_count', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=722,
  serialized_end=813,
)


_PDMOBJECTSETTERCHUNK = _descriptor.Descriptor(
  name='PdmObjectSetterChunk',
  full_name='rips.PdmObjectSetterChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='set_request', full_name='rips.PdmObjectSetterChunk.set_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doubles', full_name='rips.PdmObjectSetterChunk.doubles', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ints', full_name='rips.PdmObjectSetterChunk.ints', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strings', full_name='rips.PdmObjectSetterChunk.strings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='rips.PdmObjectSetterChunk.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=816,
  serialized_end=1007,
)


_DOUBLEARRAY = _descriptor.Descriptor(
  name='DoubleArray',
  full_name='rips.DoubleArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.DoubleArray.data', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1009,
  serialized_end=1036,
)


_INTARRAY = _descriptor.Descriptor(
  name='IntArray',
  full_name='rips.IntArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.IntArray.data', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1062,
)


_STRINGARRAY = _descriptor.Descriptor(
  name='StringArray',
  full_name='rips.StringArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='rips.StringArray.data', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1091,
)


_PDMOBJECTGETTERREPLY = _descriptor.Descriptor(
  name='PdmObjectGetterReply',
  full_name='rips.PdmObjectGetterReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='doubles', full_name='rips.PdmObjectGetterReply.doubles', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ints', full_name='rips.PdmObjectGetterReply.ints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strings', full_name='rips.PdmObjectGetterReply.strings', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='rips.PdmObjectGetterReply.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1094,
  serialized_end=1232,
)


_PDMOBJECTMETHODREQUEST = _descriptor.Descriptor(
  name='PdmObjectMethodRequest',
  full_name='rips.PdmObjectMethodRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='rips.PdmObjectMethodRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='rips.PdmObjectMethodRequest.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='rips.PdmObjectMethodRequest.params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1234,
  serialized_end=1340,
)

_PDMDESCENDANTOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMCHILDOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_CREATEPDMCHILDOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMPARENTOBJECTREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMOBJECT_PARAMETERSENTRY.containing_type = _PDMOBJECT
_PDMOBJECT.fields_by_name['parameters'].message_type = _PDMOBJECT_PARAMETERSENTRY
_PDMOBJECTARRAY.fields_by_name['objects'].message_type = _PDMOBJECT
_PDMOBJECTGETTERREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMOBJECTSETTERREQUEST.fields_by_name['request'].message_type = _PDMOBJECTGETTERREQUEST
_PDMOBJECTSETTERCHUNK.fields_by_name['set_request'].message_type = _PDMOBJECTSETTERREQUEST
_PDMOBJECTSETTERCHUNK.fields_by_name['doubles'].message_type = _DOUBLEARRAY
_PDMOBJECTSETTERCHUNK.fields_by_name['ints'].message_type = _INTARRAY
_PDMOBJECTSETTERCHUNK.fields_by_name['strings'].message_type = _STRINGARRAY
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['set_request'])
_PDMOBJECTSETTERCHUNK.fields_by_name['set_request'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['doubles'])
_PDMOBJECTSETTERCHUNK.fields_by_name['doubles'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['ints'])
_PDMOBJECTSETTERCHUNK.fields_by_name['ints'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTSETTERCHUNK.oneofs_by_name['data'].fields.append(
  _PDMOBJECTSETTERCHUNK.fields_by_name['strings'])
_PDMOBJECTSETTERCHUNK.fields_by_name['strings'].containing_oneof = _PDMOBJECTSETTERCHUNK.oneofs_by_name['data']
_PDMOBJECTGETTERREPLY.fields_by_name['doubles'].message_type = _DOUBLEARRAY
_PDMOBJECTGETTERREPLY.fields_by_name['ints'].message_type = _INTARRAY
_PDMOBJECTGETTERREPLY.fields_by_name['strings'].message_type = _STRINGARRAY
_PDMOBJECTGETTERREPLY.oneofs_by_name['data'].fields.append(
  _PDMOBJECTGETTERREPLY.fields_by_name['doubles'])
_PDMOBJECTGETTERREPLY.fields_by_name['doubles'].containing_oneof = _PDMOBJECTGETTERREPLY.oneofs_by_name['data']
_PDMOBJECTGETTERREPLY.oneofs_by_name['data'].fields.append(
  _PDMOBJECTGETTERREPLY.fields_by_name['ints'])
_PDMOBJECTGETTERREPLY.fields_by_name['ints'].containing_oneof = _PDMOBJECTGETTERREPLY.oneofs_by_name['data']
_PDMOBJECTGETTERREPLY.oneofs_by_name['data'].fields.append(
  _PDMOBJECTGETTERREPLY.fields_by_name['strings'])
_PDMOBJECTGETTERREPLY.fields_by_name['strings'].containing_oneof = _PDMOBJECTGETTERREPLY.oneofs_by_name['data']
_PDMOBJECTMETHODREQUEST.fields_by_name['object'].message_type = _PDMOBJECT
_PDMOBJECTMETHODREQUEST.fields_by_name['params'].message_type = _PDMOBJECT
DESCRIPTOR.message_types_by_name['PdmDescendantObjectRequest'] = _PDMDESCENDANTOBJECTREQUEST
DESCRIPTOR.message_types_by_name['PdmChildObjectRequest'] = _PDMCHILDOBJECTREQUEST
DESCRIPTOR.message_types_by_name['CreatePdmChildObjectRequest'] = _CREATEPDMCHILDOBJECTREQUEST
DESCRIPTOR.message_types_by_name['PdmParentObjectRequest'] = _PDMPARENTOBJECTREQUEST
DESCRIPTOR.message_types_by_name['PdmObject'] = _PDMOBJECT
DESCRIPTOR.message_types_by_name['PdmObjectArray'] = _PDMOBJECTARRAY
DESCRIPTOR.message_types_by_name['PdmObjectGetterRequest'] = _PDMOBJECTGETTERREQUEST
DESCRIPTOR.message_types_by_name['PdmObjectSetterRequest'] = _PDMOBJECTSETTERREQUEST
DESCRIPTOR.message_types_by_name['PdmObjectSetterChunk'] = _PDMOBJECTSETTERCHUNK
DESCRIPTOR.message_types_by_name['DoubleArray'] = _DOUBLEARRAY
DESCRIPTOR.message_types_by_name['IntArray'] = _INTARRAY
DESCRIPTOR.message_types_by_name['StringArray'] = _STRINGARRAY
DESCRIPTOR.message_types_by_name['PdmObjectGetterReply'] = _PDMOBJECTGETTERREPLY
DESCRIPTOR.message_types_by_name['PdmObjectMethodRequest'] = _PDMOBJECTMETHODREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PdmDescendantObjectRequest = _reflection.GeneratedProtocolMessageType('PdmDescendantObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMDESCENDANTOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmDescendantObjectRequest)
  })
_sym_db.RegisterMessage(PdmDescendantObjectRequest)

PdmChildObjectRequest = _reflection.GeneratedProtocolMessageType('PdmChildObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMCHILDOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmChildObjectRequest)
  })
_sym_db.RegisterMessage(PdmChildObjectRequest)

CreatePdmChildObjectRequest = _reflection.GeneratedProtocolMessageType('CreatePdmChildObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPDMCHILDOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.CreatePdmChildObjectRequest)
  })
_sym_db.RegisterMessage(CreatePdmChildObjectRequest)

PdmParentObjectRequest = _reflection.GeneratedProtocolMessageType('PdmParentObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMPARENTOBJECTREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmParentObjectRequest)
  })
_sym_db.RegisterMessage(PdmParentObjectRequest)

PdmObject = _reflection.GeneratedProtocolMessageType('PdmObject', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _PDMOBJECT_PARAMETERSENTRY,
    '__module__' : 'PdmObject_pb2'
    # @@protoc_insertion_point(class_scope:rips.PdmObject.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _PDMOBJECT,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObject)
  })
_sym_db.RegisterMessage(PdmObject)
_sym_db.RegisterMessage(PdmObject.ParametersEntry)

PdmObjectArray = _reflection.GeneratedProtocolMessageType('PdmObjectArray', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectArray)
  })
_sym_db.RegisterMessage(PdmObjectArray)

PdmObjectGetterRequest = _reflection.GeneratedProtocolMessageType('PdmObjectGetterRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTGETTERREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectGetterRequest)
  })
_sym_db.RegisterMessage(PdmObjectGetterRequest)

PdmObjectSetterRequest = _reflection.GeneratedProtocolMessageType('PdmObjectSetterRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTSETTERREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectSetterRequest)
  })
_sym_db.RegisterMessage(PdmObjectSetterRequest)

PdmObjectSetterChunk = _reflection.GeneratedProtocolMessageType('PdmObjectSetterChunk', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTSETTERCHUNK,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectSetterChunk)
  })
_sym_db.RegisterMessage(PdmObjectSetterChunk)

DoubleArray = _reflection.GeneratedProtocolMessageType('DoubleArray', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.DoubleArray)
  })
_sym_db.RegisterMessage(DoubleArray)

IntArray = _reflection.GeneratedProtocolMessageType('IntArray', (_message.Message,), {
  'DESCRIPTOR' : _INTARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.IntArray)
  })
_sym_db.RegisterMessage(IntArray)

StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.StringArray)
  })
_sym_db.RegisterMessage(StringArray)

PdmObjectGetterReply = _reflection.GeneratedProtocolMessageType('PdmObjectGetterReply', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTGETTERREPLY,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectGetterReply)
  })
_sym_db.RegisterMessage(PdmObjectGetterReply)

PdmObjectMethodRequest = _reflection.GeneratedProtocolMessageType('PdmObjectMethodRequest', (_message.Message,), {
  'DESCRIPTOR' : _PDMOBJECTMETHODREQUEST,
  '__module__' : 'PdmObject_pb2'
  # @@protoc_insertion_point(class_scope:rips.PdmObjectMethodRequest)
  })
_sym_db.RegisterMessage(PdmObjectMethodRequest)


_PDMOBJECT_PARAMETERSENTRY._options = None

_PDMOBJECTSERVICE = _descriptor.ServiceDescriptor(
  name='PdmObjectService',
  full_name='rips.PdmObjectService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1343,
  serialized_end=1976,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDescendantPdmObjects',
    full_name='rips.PdmObjectService.GetDescendantPdmObjects',
    index=0,
    containing_service=None,
    input_type=_PDMDESCENDANTOBJECTREQUEST,
    output_type=_PDMOBJECTARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetChildPdmObjects',
    full_name='rips.PdmObjectService.GetChildPdmObjects',
    index=1,
    containing_service=None,
    input_type=_PDMCHILDOBJECTREQUEST,
    output_type=_PDMOBJECTARRAY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAncestorPdmObject',
    full_name='rips.PdmObjectService.GetAncestorPdmObject',
    index=2,
    containing_service=None,
    input_type=_PDMPARENTOBJECTREQUEST,
    output_type=_PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateChildPdmObject',
    full_name='rips.PdmObjectService.CreateChildPdmObject',
    index=3,
    containing_service=None,
    input_type=_CREATEPDMCHILDOBJECTREQUEST,
    output_type=_PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateExistingPdmObject',
    full_name='rips.PdmObjectService.UpdateExistingPdmObject',
    index=4,
    containing_service=None,
    input_type=_PDMOBJECT,
    output_type=Definitions__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallPdmObjectGetter',
    full_name='rips.PdmObjectService.CallPdmObjectGetter',
    index=5,
    containing_service=None,
    input_type=_PDMOBJECTGETTERREQUEST,
    output_type=_PDMOBJECTGETTERREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallPdmObjectSetter',
    full_name='rips.PdmObjectService.CallPdmObjectSetter',
    index=6,
    containing_service=None,
    input_type=_PDMOBJECTSETTERCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CallPdmObjectMethod',
    full_name='rips.PdmObjectService.CallPdmObjectMethod',
    index=7,
    containing_service=None,
    input_type=_PDMOBJECTMETHODREQUEST,
    output_type=_PDMOBJECT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PDMOBJECTSERVICE)

DESCRIPTOR.services_by_name['PdmObjectService'] = _PDMOBJECTSERVICE

# @@protoc_insertion_point(module_scope)
