# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Definitions_pb2 as Definitions__pb2
import Case_pb2 as Case__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Properties.proto',
  package='rips',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10Properties.proto\x12\x04rips\x1a\x11\x44\x65\x66initions.proto\x1a\nCase.proto\"\xa1\x01\n\x1a\x41vailablePropertiesRequest\x12\'\n\x0c\x63\x61se_request\x18\x01 \x01(\x0b\x32\x11.rips.CaseRequest\x12)\n\rproperty_type\x18\x02 \x01(\x0e\x32\x12.rips.PropertyType\x12/\n\x0eporosity_model\x18\x03 \x01(\x0e\x32\x17.rips.PorosityModelType\"-\n\x13\x41vailableProperties\x12\x16\n\x0eproperty_names\x18\x01 \x03(\t\"\xd4\x01\n\x0fPropertyRequest\x12\'\n\x0c\x63\x61se_request\x18\x01 \x01(\x0b\x32\x11.rips.CaseRequest\x12)\n\rproperty_type\x18\x02 \x01(\x0e\x32\x12.rips.PropertyType\x12\x15\n\rproperty_name\x18\x03 \x01(\t\x12\x11\n\ttime_step\x18\x04 \x01(\x05\x12\x12\n\ngrid_index\x18\x05 \x01(\x05\x12/\n\x0eporosity_model\x18\x06 \x01(\x0e\x32\x17.rips.PorosityModelType\"\x19\n\x08TimeStep\x12\r\n\x05index\x18\x01 \x01(\x05\"q\n\x12PropertyInputChunk\x12\'\n\x06params\x18\x01 \x01(\x0b\x32\x15.rips.PropertyRequestH\x00\x12%\n\x06values\x18\x02 \x01(\x0b\x32\x13.rips.PropertyChunkH\x00\x42\x0b\n\tChunkType\"\x1f\n\rPropertyChunk\x12\x0e\n\x06values\x18\x01 \x03(\x01*\xc7\x01\n\x0cPropertyType\x12\x12\n\x0e\x44YNAMIC_NATIVE\x10\x00\x12\x11\n\rSTATIC_NATIVE\x10\x01\x12\r\n\tSOURSIMRL\x10\x02\x12\r\n\tGENERATED\x10\x03\x12\x12\n\x0eINPUT_PROPERTY\x10\x04\x12\x13\n\x0f\x46ORMATION_NAMES\x10\x05\x12\x14\n\x10\x46LOW_DIAGNOSTICS\x10\x06\x12\x16\n\x12INJECTION_FLOODING\x10\x07\x12\x0b\n\x07REMOVED\x10\x08\x12\x0e\n\tUNDEFINED\x10\xe7\x07\x32\xe6\x03\n\nProperties\x12W\n\x16GetAvailableProperties\x12 .rips.AvailablePropertiesRequest\x1a\x19.rips.AvailableProperties\"\x00\x12G\n\x15GetActiveCellProperty\x12\x15.rips.PropertyRequest\x1a\x13.rips.PropertyChunk\"\x00\x30\x01\x12I\n\x17GetSelectedCellProperty\x12\x15.rips.PropertyRequest\x1a\x13.rips.PropertyChunk\"\x00\x30\x01\x12\x41\n\x0fGetGridProperty\x12\x15.rips.PropertyRequest\x1a\x13.rips.PropertyChunk\"\x00\x30\x01\x12V\n\x15SetActiveCellProperty\x12\x18.rips.PropertyInputChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x12P\n\x0fSetGridProperty\x12\x18.rips.PropertyInputChunk\x1a\x1f.rips.ClientToServerStreamReply\"\x00(\x01\x62\x06proto3'
  ,
  dependencies=[Definitions__pb2.DESCRIPTOR,Case__pb2.DESCRIPTOR,])

_PROPERTYTYPE = _descriptor.EnumDescriptor(
  name='PropertyType',
  full_name='rips.PropertyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_NATIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATIC_NATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOURSIMRL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GENERATED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INPUT_PROPERTY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORMATION_NAMES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOW_DIAGNOSTICS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INJECTION_FLOODING', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=9, number=999,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=659,
  serialized_end=858,
)
_sym_db.RegisterEnumDescriptor(_PROPERTYTYPE)

PropertyType = enum_type_wrapper.EnumTypeWrapper(_PROPERTYTYPE)
DYNAMIC_NATIVE = 0
STATIC_NATIVE = 1
SOURSIMRL = 2
GENERATED = 3
INPUT_PROPERTY = 4
FORMATION_NAMES = 5
FLOW_DIAGNOSTICS = 6
INJECTION_FLOODING = 7
REMOVED = 8
UNDEFINED = 999



_AVAILABLEPROPERTIESREQUEST = _descriptor.Descriptor(
  name='AvailablePropertiesRequest',
  full_name='rips.AvailablePropertiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_request', full_name='rips.AvailablePropertiesRequest.case_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_type', full_name='rips.AvailablePropertiesRequest.property_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='porosity_model', full_name='rips.AvailablePropertiesRequest.porosity_model', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=219,
)


_AVAILABLEPROPERTIES = _descriptor.Descriptor(
  name='AvailableProperties',
  full_name='rips.AvailableProperties',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='property_names', full_name='rips.AvailableProperties.property_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=266,
)


_PROPERTYREQUEST = _descriptor.Descriptor(
  name='PropertyRequest',
  full_name='rips.PropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='case_request', full_name='rips.PropertyRequest.case_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_type', full_name='rips.PropertyRequest.property_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='property_name', full_name='rips.PropertyRequest.property_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_step', full_name='rips.PropertyRequest.time_step', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_index', full_name='rips.PropertyRequest.grid_index', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='porosity_model', full_name='rips.PropertyRequest.porosity_model', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=481,
)


_TIMESTEP = _descriptor.Descriptor(
  name='TimeStep',
  full_name='rips.TimeStep',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='rips.TimeStep.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=508,
)


_PROPERTYINPUTCHUNK = _descriptor.Descriptor(
  name='PropertyInputChunk',
  full_name='rips.PropertyInputChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='rips.PropertyInputChunk.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='rips.PropertyInputChunk.values', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ChunkType', full_name='rips.PropertyInputChunk.ChunkType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=510,
  serialized_end=623,
)


_PROPERTYCHUNK = _descriptor.Descriptor(
  name='PropertyChunk',
  full_name='rips.PropertyChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='rips.PropertyChunk.values', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=625,
  serialized_end=656,
)

_AVAILABLEPROPERTIESREQUEST.fields_by_name['case_request'].message_type = Case__pb2._CASEREQUEST
_AVAILABLEPROPERTIESREQUEST.fields_by_name['property_type'].enum_type = _PROPERTYTYPE
_AVAILABLEPROPERTIESREQUEST.fields_by_name['porosity_model'].enum_type = Case__pb2._POROSITYMODELTYPE
_PROPERTYREQUEST.fields_by_name['case_request'].message_type = Case__pb2._CASEREQUEST
_PROPERTYREQUEST.fields_by_name['property_type'].enum_type = _PROPERTYTYPE
_PROPERTYREQUEST.fields_by_name['porosity_model'].enum_type = Case__pb2._POROSITYMODELTYPE
_PROPERTYINPUTCHUNK.fields_by_name['params'].message_type = _PROPERTYREQUEST
_PROPERTYINPUTCHUNK.fields_by_name['values'].message_type = _PROPERTYCHUNK
_PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType'].fields.append(
  _PROPERTYINPUTCHUNK.fields_by_name['params'])
_PROPERTYINPUTCHUNK.fields_by_name['params'].containing_oneof = _PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType']
_PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType'].fields.append(
  _PROPERTYINPUTCHUNK.fields_by_name['values'])
_PROPERTYINPUTCHUNK.fields_by_name['values'].containing_oneof = _PROPERTYINPUTCHUNK.oneofs_by_name['ChunkType']
DESCRIPTOR.message_types_by_name['AvailablePropertiesRequest'] = _AVAILABLEPROPERTIESREQUEST
DESCRIPTOR.message_types_by_name['AvailableProperties'] = _AVAILABLEPROPERTIES
DESCRIPTOR.message_types_by_name['PropertyRequest'] = _PROPERTYREQUEST
DESCRIPTOR.message_types_by_name['TimeStep'] = _TIMESTEP
DESCRIPTOR.message_types_by_name['PropertyInputChunk'] = _PROPERTYINPUTCHUNK
DESCRIPTOR.message_types_by_name['PropertyChunk'] = _PROPERTYCHUNK
DESCRIPTOR.enum_types_by_name['PropertyType'] = _PROPERTYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AvailablePropertiesRequest = _reflection.GeneratedProtocolMessageType('AvailablePropertiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEPROPERTIESREQUEST,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.AvailablePropertiesRequest)
  })
_sym_db.RegisterMessage(AvailablePropertiesRequest)

AvailableProperties = _reflection.GeneratedProtocolMessageType('AvailableProperties', (_message.Message,), {
  'DESCRIPTOR' : _AVAILABLEPROPERTIES,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.AvailableProperties)
  })
_sym_db.RegisterMessage(AvailableProperties)

PropertyRequest = _reflection.GeneratedProtocolMessageType('PropertyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYREQUEST,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.PropertyRequest)
  })
_sym_db.RegisterMessage(PropertyRequest)

TimeStep = _reflection.GeneratedProtocolMessageType('TimeStep', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTEP,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.TimeStep)
  })
_sym_db.RegisterMessage(TimeStep)

PropertyInputChunk = _reflection.GeneratedProtocolMessageType('PropertyInputChunk', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYINPUTCHUNK,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.PropertyInputChunk)
  })
_sym_db.RegisterMessage(PropertyInputChunk)

PropertyChunk = _reflection.GeneratedProtocolMessageType('PropertyChunk', (_message.Message,), {
  'DESCRIPTOR' : _PROPERTYCHUNK,
  '__module__' : 'Properties_pb2'
  # @@protoc_insertion_point(class_scope:rips.PropertyChunk)
  })
_sym_db.RegisterMessage(PropertyChunk)



_PROPERTIES = _descriptor.ServiceDescriptor(
  name='Properties',
  full_name='rips.Properties',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=861,
  serialized_end=1347,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAvailableProperties',
    full_name='rips.Properties.GetAvailableProperties',
    index=0,
    containing_service=None,
    input_type=_AVAILABLEPROPERTIESREQUEST,
    output_type=_AVAILABLEPROPERTIES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveCellProperty',
    full_name='rips.Properties.GetActiveCellProperty',
    index=1,
    containing_service=None,
    input_type=_PROPERTYREQUEST,
    output_type=_PROPERTYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSelectedCellProperty',
    full_name='rips.Properties.GetSelectedCellProperty',
    index=2,
    containing_service=None,
    input_type=_PROPERTYREQUEST,
    output_type=_PROPERTYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetGridProperty',
    full_name='rips.Properties.GetGridProperty',
    index=3,
    containing_service=None,
    input_type=_PROPERTYREQUEST,
    output_type=_PROPERTYCHUNK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetActiveCellProperty',
    full_name='rips.Properties.SetActiveCellProperty',
    index=4,
    containing_service=None,
    input_type=_PROPERTYINPUTCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetGridProperty',
    full_name='rips.Properties.SetGridProperty',
    index=5,
    containing_service=None,
    input_type=_PROPERTYINPUTCHUNK,
    output_type=Definitions__pb2._CLIENTTOSERVERSTREAMREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROPERTIES)

DESCRIPTOR.services_by_name['Properties'] = _PROPERTIES

# @@protoc_insertion_point(module_scope)
